@@ -1,5 +1,5 @@
 package Bio::Roary::AccessoryBinaryFasta;
-$Bio::Roary::AccessoryBinaryFasta::VERSION = '3.4.2';
+$Bio::Roary::AccessoryBinaryFasta::VERSION = '3.4.3';
 # ABSTRACT: Output a FASTA file which represents the binary presence and absence of genes in the accessory genome
 
 
@@ -9,6 +9,7 @@ use Bio::Roary::AnnotateGroups;
 use Bio::Roary::AnalyseGroups;
 use Bio::Roary::Exceptions;
 use Bio::SeqIO;
+use File::Basename;
 
 has 'input_files'            => ( is => 'ro', isa => 'ArrayRef',                   required => 1 );
 has 'annotate_groups_obj'    => ( is => 'ro', isa => 'Bio::Roary::AnnotateGroups', required => 1 );
@@ -53,7 +54,9 @@ sub create_accessory_binary_fasta {
     my ($self) = @_;
     my $out_seq_io = Bio::SeqIO->new( -file => ">" . $self->output_filename, -format => 'Fasta' );
 
-    for my $filename ( @{ $self->input_files } ) {
+    for my $full_filename ( @{ $self->input_files } ) {
+        my($filename, $dirs, $suffix) = fileparse($full_filename);
+        
         my $output_sequence = '';
         my $sample_name     = $filename;
         $sample_name =~ s!\.gff\.proteome\.faa!!;
@@ -99,7 +102,7 @@ Bio::Roary::AccessoryBinaryFasta - Output a FASTA file which represents the bina
 
 =head1 VERSION
 
-version 3.4.2
+version 3.4.3
 
 =head1 SYNOPSIS
 
